pub type DefaultSolver<'a, State> = ParNoCachingSolverLel<'a, State>;Expand description
A type alias to emphasize that this is the solver that should be used by default.
Aliased Type
pub struct DefaultSolver<'a, State> { /* private fields */ }pub type DefaultSolver<'a, State> = ParNoCachingSolverLel<'a, State>;A type alias to emphasize that this is the solver that should be used by default.
pub struct DefaultSolver<'a, State> { /* private fields */ }