pub trait Cutoff {
// Required method
fn must_stop(&self) -> bool;
}Expand description
This trait encapsulates a criterion (external to the solver) which imposes to stop searching for a better solution. Typically, this is done to grant a given time budget to the search.